@@ -33,9 +33,15 @@
 #include "gstvaapidisplay_wayland_priv.h"
 #include "gstvaapiwindow_wayland.h"
 
-#define DEBUG 1
+#define DEBUG_VAAPI_DISPLAY 1
 #include "gstvaapidebug.h"
 
+#define _do_init \
+    G_ADD_PRIVATE (GstVaapiDisplayWayland);
+
+G_DEFINE_TYPE_WITH_CODE (GstVaapiDisplayWayland, gst_vaapi_display_wayland,
+    GST_TYPE_VAAPI_DISPLAY, _do_init);
+
 static const guint g_display_types = 1U << GST_VAAPI_DISPLAY_TYPE_WAYLAND;
 
 static inline const gchar *
@@ -342,26 +348,22 @@ gst_vaapi_display_wayland_create_window (GstVaapiDisplay * display,
 }
 
 static void
-gst_vaapi_display_wayland_init (GstVaapiDisplay * display)
+gst_vaapi_display_wayland_init (GstVaapiDisplayWayland * display)
 {
   GstVaapiDisplayWaylandPrivate *const priv =
-      GST_VAAPI_DISPLAY_WAYLAND_GET_PRIVATE (display);
+      gst_vaapi_display_wayland_get_instance_private (display);
 
+  display->priv = priv;
   priv->event_fd = -1;
 }
 
 static void
 gst_vaapi_display_wayland_class_init (GstVaapiDisplayWaylandClass * klass)
 {
-  GstVaapiMiniObjectClass *const object_class =
-      GST_VAAPI_MINI_OBJECT_CLASS (klass);
   GstVaapiDisplayClass *const dpy_class = GST_VAAPI_DISPLAY_CLASS (klass);
 
-  gst_vaapi_display_class_init (&klass->parent_class);
-
-  object_class->size = sizeof (GstVaapiDisplayWayland);
   dpy_class->display_type = GST_VAAPI_DISPLAY_TYPE_WAYLAND;
-  dpy_class->init = gst_vaapi_display_wayland_init;
+
   dpy_class->bind_display = gst_vaapi_display_wayland_bind_display;
   dpy_class->open_display = gst_vaapi_display_wayland_open_display;
   dpy_class->close_display = gst_vaapi_display_wayland_close_display;
@@ -371,19 +373,6 @@ gst_vaapi_display_wayland_class_init (GstVaapiDisplayWaylandClass * klass)
   dpy_class->create_window = gst_vaapi_display_wayland_create_window;
 }
 
-static inline const GstVaapiDisplayClass *
-gst_vaapi_display_wayland_class (void)
-{
-  static GstVaapiDisplayWaylandClass g_class;
-  static gsize g_class_init = FALSE;
-
-  if (g_once_init_enter (&g_class_init)) {
-    gst_vaapi_display_wayland_class_init (&g_class);
-    g_once_init_leave (&g_class_init, TRUE);
-  }
-  return GST_VAAPI_DISPLAY_CLASS (&g_class);
-}
-
 /**
  * gst_vaapi_display_wayland_new:
  * @display_name: the Wayland display name
@@ -397,8 +386,9 @@ gst_vaapi_display_wayland_class (void)
 GstVaapiDisplay *
 gst_vaapi_display_wayland_new (const gchar * display_name)
 {
-  return gst_vaapi_display_new (gst_vaapi_display_wayland_class (),
-      GST_VAAPI_DISPLAY_INIT_FROM_DISPLAY_NAME, (gpointer) display_name);
+  return gst_vaapi_display_new (g_object_new (GST_TYPE_VAAPI_DISPLAY_WAYLAND,
+          NULL), GST_VAAPI_DISPLAY_INIT_FROM_DISPLAY_NAME,
+      (gpointer) display_name);
 }
 
 /**
@@ -417,8 +407,8 @@ gst_vaapi_display_wayland_new_with_display (struct wl_display * wl_display)
 {
   g_return_val_if_fail (wl_display, NULL);
 
-  return gst_vaapi_display_new (gst_vaapi_display_wayland_class (),
-      GST_VAAPI_DISPLAY_INIT_FROM_NATIVE_DISPLAY, wl_display);
+  return gst_vaapi_display_new (g_object_new (GST_TYPE_VAAPI_DISPLAY_WAYLAND,
+          NULL), GST_VAAPI_DISPLAY_INIT_FROM_NATIVE_DISPLAY, wl_display);
 }
 
 /**
