@@ -180,8 +180,7 @@ gst_vaapi_create_display_from_gl_context (GstObject * gl_context_object)
 #if USE_X11 && GST_GL_HAVE_WINDOW_X11
         if (!display_type)
           display_type = GST_VAAPI_DISPLAY_TYPE_X11;
-#endif
-#if USE_WAYLAND && GST_GL_HAVE_WINDOW_WAYLAND
+#elif USE_WAYLAND && GST_GL_HAVE_WINDOW_WAYLAND
         if (!display_type)
           display_type = GST_VAAPI_DISPLAY_TYPE_WAYLAND;
 #endif
